@@ -8,13 +8,14 @@ from nile.core.account import Account
 from nile.core.call_or_invoke import call_or_invoke as call_or_invoke_command
 from nile.core.clean import clean as clean_command
 from nile.core.compile import compile as compile_command
+from nile.core.declare import declare as declare_command
 from nile.core.deploy import deploy as deploy_command
 from nile.core.init import init as init_command
 from nile.core.install import install as install_command
 from nile.core.node import node as node_command
+from nile.core.plugins import load_plugins
 from nile.core.run import run as run_command
 from nile.core.test import test as test_command
-from nile.core.plugins import load_plugins
 from nile.core.version import version as version_command
 from nile.utils.debug import debug as debug_command
 
@@ -28,7 +29,7 @@ def network_option(f):
     return click.option(  # noqa: E731
         "--network",
         envvar="STARKNET_NETWORK",
-        default="127.0.0.1",
+        default="localhost",
         help=f"Select network, one of {NETWORKS}",
         callback=_validate_network,
     )(f)
@@ -41,7 +42,7 @@ def _validate_network(_ctx, _param, value):
         return "goerli"
     # normalize localhost
     if "localhost" in value or "127.0.0.1" in value:
-        return "127.0.0.1"
+        return "localhost"
     # check if value is accepted
     if value in NETWORKS:
         return value
@@ -85,6 +86,15 @@ def deploy(artifact, arguments, network, alias):
     deploy_command(artifact, arguments, network, alias)
 
 
+@cli.command()
+@click.argument("artifact", nargs=1)
+@network_option
+@click.option("--alias")
+def declare(artifact, network, alias):
+    """Declare StarkNet smart contract."""
+    declare_command(artifact, network, alias)
+
+
 @cli.command()
 @click.argument("signer", nargs=1)
 @network_option
@@ -98,8 +108,9 @@ def setup(signer, network):
 @click.argument("contract_name", nargs=1)
 @click.argument("method", nargs=1)
 @click.argument("params", nargs=-1)
+@click.option("--max_fee", nargs=1)
 @network_option
-def send(signer, contract_name, method, params, network):
+def send(signer, contract_name, method, params, network, max_fee=None):
     """Invoke a contract's method through an Account. Same usage as nile invoke."""
     account = Account(signer, network)
     print(
@@ -107,7 +118,7 @@ def send(signer, contract_name, method, params, network):
             method, contract_name, [x for x in params]
         )
     )
-    out = account.send(contract_name, method, params)
+    out = account.send(contract_name, method, params, max_fee=max_fee)
     print(out)
 
 
@@ -115,10 +126,13 @@ def send(signer, contract_name, method, params, network):
 @click.argument("contract_name", nargs=1)
 @click.argument("method", nargs=1)
 @click.argument("params", nargs=-1)
+@click.option("--max_fee", nargs=1)
 @network_option
-def invoke(contract_name, method, params, network):
+def invoke(contract_name, method, params, network, max_fee=None):
     """Invoke functions of StarkNet smart contracts."""
-    out = call_or_invoke_command(contract_name, "invoke", method, params, network)
+    out = call_or_invoke_command(
+        contract_name, "invoke", method, params, network, max_fee=max_fee
+    )
     print(out)
 
 
@@ -180,12 +194,12 @@ def clean():
 
 @cli.command()
 @click.option("--host", default="127.0.0.1")
-@click.option("--port", default=5000)
+@click.option("--port", default=5050)
 def node(host, port):
     """Start StarkNet local network.
 
     $ nile node
-      Start StarkNet local network at port 5000
+      Start StarkNet local network at port 5050
 
     $ nile node --host HOST --port 5001
       Start StarkNet network on address HOST listening at port 5001
